@@ -6,7 +6,8 @@
 #' @param el_value the value to be added to the log.rx element
 #'
 #' @return Nothing
-#' @export
+#'
+#' @noRd
 #'
 set_log_element <- function(el_key, el_value){
    # check if key is currently in the log.rx environment
@@ -29,7 +30,8 @@ set_log_element <- function(el_key, el_value){
 #' @param el_key the key of the element in log.rx to be fetched
 #'
 #' @return Value of corresponding element from log.rx environment
-#' @export
+#'
+#' @noRd
 #'
 get_log_element <- function(el_key){
    if (!(el_key %in% names(getOption('log.rx')))) {
@@ -57,7 +59,8 @@ get_log_element <- function(el_key){
 #' @param log_path The log path
 #'
 #' @return Nothing
-#' @export
+#'
+#' @noRd
 #'
 set_log_name_path <- function(log_name = NA, log_path = NA) {
    # If log_name was previously assigned, generate warning
@@ -110,7 +113,12 @@ run_safely <- function(file) "dummy"
 #' Dummy function for running a file
 #' @noRd
 run_file <- function(file){
-   source(file, local = TRUE)
+   if (is.null(getOption("log.rx.exec.env"))){
+      exec_env <- new.env(parent=globalenv())
+   } else{
+      exec_env <- getOption("log.rx.exec.env")
+   }
+   source(file, local = exec_env)
 }
 
 #' Safely run an R script and record results, outputs, messages, errors, warnings
@@ -121,7 +129,8 @@ run_file <- function(file){
 #' @param file File to run
 #'
 #' @return Nothing
-#' @export
+#'
+#' @noRd
 #'
 run_safely_loudly <- function(file) {
    ret <- loudly(run_safely(file))
@@ -130,6 +139,7 @@ run_safely_loudly <- function(file) {
    set_log_element("result", ret$result$result)
    set_log_element("warnings", ret$warnings)
    set_log_element("errors", ret$result$error)
+   set_log_element("hash_sum", digest::sha1(readLines(file)))
 
    # Session Info
    set_log_element("session_info", get_session_info())
